@@ -16,6 +16,7 @@ import (
 
 	"github.com/spf13/afero"
 
+	"github.com/aws/aws-sdk-go/aws/arn"
 	"github.com/aws/copilot-cli/internal/pkg/addon"
 	"github.com/aws/copilot-cli/internal/pkg/aws/apprunner"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
@@ -60,6 +61,13 @@ var (
 	fmtErrInvalidEngineType        = "invalid engine type %s: must be one of %s"
 	fmtErrInvalidDBNameCharacters  = "invalid database name %s: must contain only alphanumeric characters and underscore; should start with a letter"
 	errInvalidSecretNameCharacters = errors.New("value must contain only letters, numbers, periods, hyphens and underscores")
+
+	// Topic subscription errors.
+	errMissingPublishTopicField = errors.New("field `publish.topics[].name` cannot be empty")
+	errInvalidPubSubTopicName   = errors.New("topic names can only contain letters, numbers, underscores, and hyphens")
+	errSubscribeBadFormat       = errors.New("value must be of the form <serviceName>:<topicName>")
+
+	fmtErrTopicSubscriptionNotAllowed = "SNS topic %s does not exist in environment %s"
 )
 
 const fmtErrValueBadSize = "value must be between %d and %d characters in length"
@@ -139,6 +147,13 @@ var (
 // https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PutParameter.html#systemsmanager-PutParameter-request-Name
 var secretParameterNameRegExp = regexp.MustCompile("^[a-zA-Z0-9_.-]+$")
 
+var (
+	awsSNSTopicRegexp       = regexp.MustCompile(`^[a-zA-Z0-9_-]*$`) // Validates that an expression contains only letters, numbers, underscores, and hyphens.
+	regexpMatchSubscription = regexp.MustCompile(`^(\S+):(\S+)`)     // Validates that an expression contains the format serviceName:topicName
+)
+
+var resourceNameFormat = "%s-%s-%s-%s" // Format for copilot resource names of form app-env-svc-name
+
 const regexpFindAllMatches = -1
 
 func validateAppName(val interface{}) error {
@@ -626,6 +641,88 @@ func validateLSIs(val interface{}) error {
 	return nil
 }
 
+func validateSubscribe(noSubscription bool, subscribeTags []string) error {
+	// --no-subscriptions and --subscribe are mutually exclusive.
+	if noSubscription && len(subscribeTags) != 0 {
+		return fmt.Errorf("validate subscribe configuration: cannot specify both --%s and --%s", noSubscriptionFlag, subscribeTopicsFlag)
+	}
+	if len(subscribeTags) != 0 {
+		if err := validateSubscriptions(subscribeTags); err != nil {
+			return err
+		}
+	}
+
+	return nil
+}
+
+func validateSubscriptions(val interface{}) error {
+	s, ok := val.([]string)
+	if !ok {
+		return errValueNotAStringSlice
+	}
+	for _, sub := range s {
+		err := validateSubscriptionKey(sub)
+		if err != nil {
+			return err
+		}
+	}
+	return nil
+}
+
+func validateSubscriptionKey(val interface{}) error {
+	s, ok := val.(string)
+	if !ok {
+		return errValueNotAString
+	}
+	sub, err := parseSerializedSubscription(s)
+	if err != nil {
+		return errSubscribeBadFormat
+	}
+	err = validatePubSubName(sub.Name)
+	if err != nil {
+		return fmt.Errorf("invalid topic subscription topic name `%s`: %w", sub.Name, err)
+	}
+	err = basicNameValidation(sub.Service)
+	if err != nil {
+		return fmt.Errorf("invalid topic subscription service name `%s`: %w", sub.Service, err)
+	}
+	return nil
+}
+
+// ValidatePubSubName validates naming is correct for topics in publishing/subscribing cases, such as naming for a
+// SNS Topic intended for a publisher.
+func validatePubSubName(name string) error {
+	if len(name) == 0 {
+		return errMissingPublishTopicField
+	}
+
+	// Name must contain letters, numbers, and can't use special characters besides underscores and hyphens.
+	if !awsSNSTopicRegexp.MatchString(name) {
+		return errInvalidPubSubTopicName
+	}
+
+	return nil
+}
+
+func validateTopicsExist(subscriptions []manifest.TopicSubscription, topicARNs []string, app, env string) error {
+	validTopicResources := make([]string, 0, len(topicARNs))
+	for _, topic := range topicARNs {
+		parsedTopic, err := arn.Parse(topic)
+		if err != nil {
+			continue
+		}
+		validTopicResources = append(validTopicResources, parsedTopic.Resource)
+	}
+
+	for _, ts := range subscriptions {
+		topicName := fmt.Sprintf(resourceNameFormat, app, env, ts.Service, ts.Name)
+		if !contains(topicName, validTopicResources) {
+			return fmt.Errorf(fmtErrTopicSubscriptionNotAllowed, topicName, env)
+		}
+	}
+	return nil
+}
+
 func prettify(inputStrings []string) string {
 	prettyTypes := template.QuoteSliceFunc(inputStrings)
 	return strings.Join(prettyTypes, ", ")
