@@ -17,6 +17,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/template"
+	"github.com/aws/copilot-cli/internal/pkg/template/override"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
 )
@@ -40,6 +41,10 @@ func (m mockTemplater) Template() (string, error) {
 	return m.tpl, nil
 }
 
+var mockCloudFormationOverrideFunc = func(overrideRules []override.Rule, origTemp []byte) ([]byte, error) {
+	return origTemp, nil
+}
+
 func TestLoadBalancedWebService_StackName(t *testing.T) {
 	testCases := map[string]struct {
 		inSvcName string
@@ -105,7 +110,7 @@ func TestLoadBalancedWebService_Template(t *testing.T) {
 	testLBWebServiceManifest.ImageConfig.HealthCheck = &manifest.ContainerHealthCheck{
 		Retries: aws.Int(5),
 	}
-	testLBWebServiceManifest.Alias = aws.String("mockAlias")
+	testLBWebServiceManifest.Alias = &manifest.Alias{String: aws.String("mockAlias")}
 	testLBWebServiceManifest.EntryPoint = &manifest.EntryPointOverride{
 		String:      nil,
 		StringSlice: []string{"/bin/echo", "hello"},
@@ -302,6 +307,7 @@ Outputs:
 							Region:    "us-west-2",
 						},
 					},
+					taskDefOverrideFunc: mockCloudFormationOverrideFunc,
 				},
 				manifest: testLBWebServiceManifest,
 			}
