@@ -14,6 +14,7 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/addon"
 
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/stack/mocks"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/template"
@@ -373,6 +374,109 @@ Outputs:
 	}
 }
 
+func TestRequestDrivenWebService_Parameters(t *testing.T) {
+	testCases := map[string]struct {
+		imageConfig    manifest.ImageWithPort
+		instanceConfig manifest.AppRunnerInstanceConfig
+
+		wantedParams []*cloudformation.Parameter
+		wantedError  error
+	}{
+		"all required fields specified": {
+			imageConfig: manifest.ImageWithPort{
+				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
+				Port:  aws.Uint16(80),
+			},
+			instanceConfig: manifest.AppRunnerInstanceConfig{
+				CPU:    aws.Int(1024),
+				Memory: aws.Int(1024),
+			},
+			wantedParams: []*cloudformation.Parameter{{
+				ParameterKey:   aws.String("AppName"),
+				ParameterValue: aws.String("phonetool"),
+			}, {
+				ParameterKey:   aws.String("EnvName"),
+				ParameterValue: aws.String("test"),
+			}, {
+				ParameterKey:   aws.String("WorkloadName"),
+				ParameterValue: aws.String("frontend"),
+			}, {
+				ParameterKey:   aws.String("ContainerImage"),
+				ParameterValue: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest"),
+			}, {
+				ParameterKey:   aws.String("AddonsTemplateURL"),
+				ParameterValue: aws.String(""),
+			}, {
+				ParameterKey:   aws.String(RDWkldImageRepositoryType),
+				ParameterValue: aws.String("ECR_PUBLIC"),
+			}, {
+				ParameterKey:   aws.String(WorkloadContainerPortParamKey),
+				ParameterValue: aws.String("80"),
+			}, {
+				ParameterKey:   aws.String(RDWkldInstanceCPUParamKey),
+				ParameterValue: aws.String("1024"),
+			}, {
+				ParameterKey:   aws.String(RDWkldInstanceMemoryParamKey),
+				ParameterValue: aws.String("1024"),
+			}},
+		},
+		"error when port unspecified": {
+			imageConfig: manifest.ImageWithPort{
+				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
+			},
+			instanceConfig: manifest.AppRunnerInstanceConfig{
+				CPU:    aws.Int(1024),
+				Memory: aws.Int(1024),
+			},
+			wantedError: errors.New("field `image.port` is required for Request Driven Web Services"),
+		},
+		"error when CPU unspecified": {
+			imageConfig: manifest.ImageWithPort{
+				Port:  aws.Uint16(80),
+				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
+			},
+			instanceConfig: manifest.AppRunnerInstanceConfig{
+				Memory: aws.Int(1024),
+			},
+			wantedError: errors.New("field `cpu` is required for Request Driven Web Services"),
+		},
+		"error when memory unspecified": {
+			imageConfig: manifest.ImageWithPort{
+				Port:  aws.Uint16(80),
+				Image: manifest.Image{Location: aws.String("public.ecr.aws/aws-containers/hello-app-runner:latest")},
+			},
+			instanceConfig: manifest.AppRunnerInstanceConfig{
+				CPU: aws.Int(1024),
+			},
+			wantedError: errors.New("field `memory` is required for Request Driven Web Services"),
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			c := &RequestDrivenWebService{
+				appRunnerWkld: &appRunnerWkld{
+					wkld: &wkld{
+						name:  aws.StringValue(testRDWebServiceManifest.Name),
+						env:   testEnvName,
+						app:   testAppName,
+						image: tc.imageConfig,
+					},
+					instanceConfig: tc.instanceConfig,
+					imageConfig:    tc.imageConfig,
+				},
+				manifest: testRDWebServiceManifest,
+			}
+			p, err := c.Parameters()
+			if tc.wantedError != nil {
+				require.EqualError(t, err, tc.wantedError.Error())
+			} else {
+				require.NoError(t, err)
+				require.Equal(t, tc.wantedParams, p)
+			}
+		})
+	}
+}
+
 func TestRequestDrivenWebService_SerializedParameters(t *testing.T) {
 	testCases := map[string]struct {
 		mockDependencies func(ctrl *gomock.Controller, c *RequestDrivenWebService)
