@@ -24,35 +24,26 @@ const (
 
 // BackendServiceDescriber retrieves information about a backend service.
 type BackendServiceDescriber struct {
-	app             string
-	svc             string
-	enableResources bool
+	*ecsServiceDescriber
 
-	store          DeployedEnvServicesLister
-	svcDescriber   map[string]ecsSvcDescriber
-	envDescriber   map[string]envDescriber
-	initDescribers func(string) error
-}
-
-// NewBackendServiceConfig contains fields that initiates BackendServiceDescriber struct.
-type NewBackendServiceConfig struct {
-	NewServiceConfig
-	EnableResources bool
-	DeployStore     DeployedEnvServicesLister
+	envDescriber map[string]envDescriber
 }
 
 // NewBackendServiceDescriber instantiates a backend service describer.
-func NewBackendServiceDescriber(opt NewBackendServiceConfig) (*BackendServiceDescriber, error) {
+func NewBackendServiceDescriber(opt NewServiceConfig) (*BackendServiceDescriber, error) {
 	describer := &BackendServiceDescriber{
-		app:             opt.App,
-		svc:             opt.Svc,
-		enableResources: opt.EnableResources,
-		store:           opt.DeployStore,
-		svcDescriber:    make(map[string]ecsSvcDescriber),
-		envDescriber:    make(map[string]envDescriber),
+		ecsServiceDescriber: &ecsServiceDescriber{
+			app:               opt.App,
+			svc:               opt.Svc,
+			enableResources:   opt.EnableResources,
+			store:             opt.DeployStore,
+			svcStackDescriber: make(map[string]ecsStackDescriber),
+		},
+
+		envDescriber: make(map[string]envDescriber),
 	}
 	describer.initDescribers = func(env string) error {
-		if _, ok := describer.svcDescriber[env]; ok {
+		if _, ok := describer.svcStackDescriber[env]; ok {
 			return nil
 		}
 		d, err := NewECSServiceDescriber(NewServiceConfig{
@@ -64,7 +55,7 @@ func NewBackendServiceDescriber(opt NewBackendServiceConfig) (*BackendServiceDes
 		if err != nil {
 			return err
 		}
-		describer.svcDescriber[env] = d
+		describer.svcStackDescriber[env] = d
 		envDescr, err := NewEnvDescriber(NewEnvDescriberConfig{
 			App:         opt.App,
 			Env:         env,
@@ -79,32 +70,6 @@ func NewBackendServiceDescriber(opt NewBackendServiceConfig) (*BackendServiceDes
 	return describer, nil
 }
 
-// URI returns the service discovery namespace and is used to make
-// BackendServiceDescriber have the same signature as WebServiceDescriber.
-func (d *BackendServiceDescriber) URI(envName string) (string, error) {
-	if err := d.initDescribers(envName); err != nil {
-		return "", err
-	}
-	svcStackParams, err := d.svcDescriber[envName].Params()
-	if err != nil {
-		return "", fmt.Errorf("get stack parameters for environment %s: %w", envName, err)
-	}
-	port := svcStackParams[cfnstack.LBWebServiceContainerPortParamKey]
-	if port == cfnstack.NoExposedContainerPort {
-		return BlankServiceDiscoveryURI, nil
-	}
-	endpoint, err := d.envDescriber[envName].ServiceDiscoveryEndpoint()
-	if err != nil {
-		return "nil", fmt.Errorf("retrieve service discovery endpoint for environment %s: %w", envName, err)
-	}
-	s := serviceDiscovery{
-		Service:  d.svc,
-		Port:     port,
-		Endpoint: endpoint,
-	}
-	return s.String(), nil
-}
-
 // Describe returns info of a backend service.
 func (d *BackendServiceDescriber) Describe() (HumanJSONStringer, error) {
 	environments, err := d.store.ListEnvironmentsDeployedTo(d.app, d.svc)
@@ -121,7 +86,7 @@ func (d *BackendServiceDescriber) Describe() (HumanJSONStringer, error) {
 		if err != nil {
 			return nil, err
 		}
-		svcParams, err := d.svcDescriber[env].Params()
+		svcParams, err := d.svcStackDescriber[env].Params()
 		if err != nil {
 			return nil, fmt.Errorf("get stack parameters for environment %s: %w", env, err)
 		}
@@ -147,12 +112,12 @@ func (d *BackendServiceDescriber) Describe() (HumanJSONStringer, error) {
 			},
 			Tasks: svcParams[cfnstack.WorkloadTaskCountParamKey],
 		})
-		backendSvcEnvVars, err := d.svcDescriber[env].EnvVars()
+		backendSvcEnvVars, err := d.svcStackDescriber[env].EnvVars()
 		if err != nil {
 			return nil, fmt.Errorf("retrieve environment variables: %w", err)
 		}
 		envVars = append(envVars, flattenContainerEnvVars(env, backendSvcEnvVars)...)
-		webSvcSecrets, err := d.svcDescriber[env].Secrets()
+		webSvcSecrets, err := d.svcStackDescriber[env].Secrets()
 		if err != nil {
 			return nil, fmt.Errorf("retrieve secrets: %w", err)
 		}
@@ -166,7 +131,7 @@ func (d *BackendServiceDescriber) Describe() (HumanJSONStringer, error) {
 			if err != nil {
 				return nil, err
 			}
-			stackResources, err := d.svcDescriber[env].ServiceStackResources()
+			stackResources, err := d.svcStackDescriber[env].ServiceStackResources()
 			if err != nil {
 				return nil, fmt.Errorf("retrieve service resources: %w", err)
 			}
