@@ -13,13 +13,6 @@ const (
 	backendSvcManifestPath = "workloads/services/backend/manifest.yml"
 )
 
-// BackendServiceProps represents the configuration needed to create a backend service.
-type BackendServiceProps struct {
-	WorkloadProps
-	Port        uint16
-	HealthCheck *ContainerHealthCheck // Optional healthcheck configuration.
-}
-
 // BackendService holds the configuration to create a backend service manifest.
 type BackendService struct {
 	Workload             `yaml:",inline"`
@@ -32,13 +25,21 @@ type BackendService struct {
 
 // BackendServiceConfig holds the configuration that can be overridden per environments.
 type BackendServiceConfig struct {
-	ImageConfig   ImageWithPortAndHealthcheck `yaml:"image,flow"`
-	ImageOverride `yaml:",inline"`
-	TaskConfig    `yaml:",inline"`
-	*Logging      `yaml:"logging,flow"`
-	Sidecars      map[string]*SidecarConfig `yaml:"sidecars"`
-	Network       *NetworkConfig            `yaml:"network"`
-	Publish       *PublishConfig            `yaml:"publish"`
+	ImageConfig      ImageWithPortAndHealthcheck `yaml:"image,flow"`
+	ImageOverride    `yaml:",inline"`
+	TaskConfig       `yaml:",inline"`
+	*Logging         `yaml:"logging,flow"`
+	Sidecars         map[string]*SidecarConfig `yaml:"sidecars"`
+	Network          *NetworkConfig            `yaml:"network"`
+	Publish          *PublishConfig            `yaml:"publish"`
+	TaskDefOverrides []OverrideRule            `yaml:"taskdef_overrides"`
+}
+
+// BackendServiceProps represents the configuration needed to create a backend service.
+type BackendServiceProps struct {
+	WorkloadProps
+	Port        uint16
+	HealthCheck *ContainerHealthCheck // Optional healthcheck configuration.
 }
 
 // NewBackendService applies the props to a default backend service configuration with
@@ -68,6 +69,24 @@ func (s *BackendService) MarshalBinary() ([]byte, error) {
 	return content.Bytes(), nil
 }
 
+// Port returns the exposed the exposed port in the manifest.
+// If the backend service is not meant to be reachable, then ok is set to false.
+func (s *BackendService) Port() (port uint16, ok bool) {
+	value := s.BackendServiceConfig.ImageConfig.Port
+	if value == nil {
+		return 0, false
+	}
+	return aws.Uint16Value(value), true
+}
+
+// Publish returns the list of topics where notifications can be published.
+func (s *BackendService) Publish() []Topic {
+	if s.BackendServiceConfig.Publish == nil {
+		return nil
+	}
+	return s.BackendServiceConfig.Publish.Topics
+}
+
 // BuildRequired returns if the service requires building from the local Dockerfile.
 func (s *BackendService) BuildRequired() (bool, error) {
 	return requiresBuild(s.ImageConfig.Image)
@@ -90,18 +109,14 @@ func (s BackendService) ApplyEnv(envName string) (WorkloadManifest, error) {
 		return &s, nil
 	}
 
-	envCount := overrideConfig.TaskConfig.Count
-	if !envCount.IsEmpty() {
-		s.TaskConfig.Count = envCount
-	}
-
 	// Apply overrides to the original service s.
-	err := mergo.Merge(&s, BackendService{
-		BackendServiceConfig: *overrideConfig,
-	}, mergo.WithOverride, mergo.WithOverwriteWithEmptyValue, mergo.WithTransformers(workloadTransformer{}))
-
-	if err != nil {
-		return nil, err
+	for _, t := range defaultTransformers {
+		err := mergo.Merge(&s, BackendService{
+			BackendServiceConfig: *overrideConfig,
+		}, mergo.WithOverride, mergo.WithTransformers(t))
+		if err != nil {
+			return nil, err
+		}
 	}
 	s.Environments = nil
 	return &s, nil
