@@ -45,6 +45,7 @@ type ScheduledJobConfig struct {
 	JobFailureHandlerConfig `yaml:",inline"`
 	Network                 *NetworkConfig `yaml:"network"`
 	Publish                 *PublishConfig `yaml:"publish"`
+	TaskDefOverrides        []OverrideRule `yaml:"taskdef_overrides"`
 }
 
 // JobTriggerConfig represents the configuration for the event that triggers the job.
@@ -67,30 +68,6 @@ type ScheduledJobProps struct {
 	Retries     int
 }
 
-// newDefaultScheduledJob returns an empty ScheduledJob with only the default values set.
-func newDefaultScheduledJob() *ScheduledJob {
-	return &ScheduledJob{
-		Workload: Workload{
-			Type: aws.String(ScheduledJobType),
-		},
-		ScheduledJobConfig: ScheduledJobConfig{
-			ImageConfig: ImageWithHealthcheck{},
-			TaskConfig: TaskConfig{
-				CPU:    aws.Int(256),
-				Memory: aws.Int(512),
-				Count: Count{
-					Value: aws.Int(1),
-				},
-			},
-			Network: &NetworkConfig{
-				VPC: &vpcConfig{
-					Placement: stringP(PublicSubnetPlacement),
-				},
-			},
-		},
-	}
-}
-
 // NewScheduledJob creates a new scheduled job object.
 func NewScheduledJob(props *ScheduledJobProps) *ScheduledJob {
 	job := newDefaultScheduledJob()
@@ -124,18 +101,28 @@ func (j ScheduledJob) ApplyEnv(envName string) (WorkloadManifest, error) {
 	if !ok {
 		return &j, nil
 	}
-	// Apply overrides to the original job
-	err := mergo.Merge(&j, ScheduledJob{
-		ScheduledJobConfig: *overrideConfig,
-	}, mergo.WithOverride, mergo.WithOverwriteWithEmptyValue, mergo.WithTransformers(workloadTransformer{}))
 
-	if err != nil {
-		return nil, err
+	// Apply overrides to the original job
+	for _, t := range defaultTransformers {
+		err := mergo.Merge(&j, ScheduledJob{
+			ScheduledJobConfig: *overrideConfig,
+		}, mergo.WithOverride, mergo.WithTransformers(t))
+		if err != nil {
+			return nil, err
+		}
 	}
 	j.Environments = nil
 	return &j, nil
 }
 
+// Publish returns the list of topics where notifications can be published.
+func (j *ScheduledJob) Publish() []Topic {
+	if j.ScheduledJobConfig.Publish == nil {
+		return nil
+	}
+	return j.ScheduledJobConfig.Publish.Topics
+}
+
 // BuildArgs returns a docker.BuildArguments object for the job given a workspace root.
 func (j *ScheduledJob) BuildArgs(wsRoot string) *DockerBuildArgs {
 	return j.ImageConfig.BuildConfig(wsRoot)
@@ -150,3 +137,27 @@ func (j *ScheduledJob) BuildRequired() (bool, error) {
 func JobDockerfileBuildRequired(job interface{}) (bool, error) {
 	return dockerfileBuildRequired("job", job)
 }
+
+// newDefaultScheduledJob returns an empty ScheduledJob with only the default values set.
+func newDefaultScheduledJob() *ScheduledJob {
+	return &ScheduledJob{
+		Workload: Workload{
+			Type: aws.String(ScheduledJobType),
+		},
+		ScheduledJobConfig: ScheduledJobConfig{
+			ImageConfig: ImageWithHealthcheck{},
+			TaskConfig: TaskConfig{
+				CPU:    aws.Int(256),
+				Memory: aws.Int(512),
+				Count: Count{
+					Value: aws.Int(1),
+				},
+			},
+			Network: &NetworkConfig{
+				VPC: &vpcConfig{
+					Placement: stringP(PublicSubnetPlacement),
+				},
+			},
+		},
+	}
+}
