@@ -5,11 +5,8 @@ package manifest
 
 import (
 	"errors"
-	"fmt"
 	"time"
 
-	"github.com/aws/copilot-cli/internal/pkg/exec"
-
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/imdario/mergo"
@@ -21,9 +18,8 @@ const (
 
 // Default values for HTTPHealthCheck for a load balanced web service.
 const (
-	DefaultHealthCheckPath                = "/"
-	DefaultHealthCheckDeregistrationDelay = 60
-	DefaultHealthCheckGracePeriod         = 60
+	DefaultHealthCheckPath        = "/"
+	DefaultHealthCheckGracePeriod = 60
 )
 
 var (
@@ -49,27 +45,15 @@ type LoadBalancedWebService struct {
 
 // LoadBalancedWebServiceConfig holds the configuration for a load balanced web service.
 type LoadBalancedWebServiceConfig struct {
-	ImageConfig   ImageWithPortAndHealthcheck `yaml:"image,flow"`
-	ImageOverride `yaml:",inline"`
-	RoutingRule   `yaml:"http,flow"`
-	TaskConfig    `yaml:",inline"`
-	*Logging      `yaml:"logging,flow"`
-	Sidecars      map[string]*SidecarConfig `yaml:"sidecars"`
-	Network       *NetworkConfig            `yaml:"network"` // TODO: the type needs to be updated after we upgrade mergo
-	Publish       *PublishConfig            `yaml:"publish"`
-}
-
-// RoutingRule holds the path to route requests to the service.
-type RoutingRule struct {
-	Path                *string                 `yaml:"path"`
-	HealthCheck         HealthCheckArgsOrString `yaml:"healthcheck"`
-	Stickiness          *bool                   `yaml:"stickiness"`
-	Alias               *string                 `yaml:"alias"`
-	DeregistrationDelay *time.Duration          `yaml:"deregistration_delay"`
-	// TargetContainer is the container load balancer routes traffic to.
-	TargetContainer          *string   `yaml:"target_container"`
-	TargetContainerCamelCase *string   `yaml:"targetContainer"`    // "targetContainerCamelCase" for backwards compatibility
-	AllowedSourceIps         *[]string `yaml:"allowed_source_ips"` // TODO: the type needs to be updated after we upgrade mergo
+	ImageConfig      ImageWithPortAndHealthcheck `yaml:"image,flow"`
+	ImageOverride    `yaml:",inline"`
+	RoutingRule      `yaml:"http,flow"`
+	TaskConfig       `yaml:",inline"`
+	*Logging         `yaml:"logging,flow"`
+	Sidecars         map[string]*SidecarConfig `yaml:"sidecars"`
+	Network          *NetworkConfig            `yaml:"network"` // TODO: the type needs to be updated after we upgrade mergo
+	Publish          *PublishConfig            `yaml:"publish"`
+	TaskDefOverrides []OverrideRule            `yaml:"taskdef_overrides"`
 }
 
 // LoadBalancedWebServiceProps contains properties for creating a new load balanced fargate service manifest.
@@ -137,19 +121,25 @@ func (s *LoadBalancedWebService) MarshalBinary() ([]byte, error) {
 	return content.Bytes(), nil
 }
 
+// Port returns the exposed port in the manifest.
+// A LoadBalancedWebService always has a port exposed therefore the boolean is always true.
+func (s *LoadBalancedWebService) Port() (port uint16, ok bool) {
+	return aws.Uint16Value(s.ImageConfig.Port), true
+}
+
+// Publish returns the list of topics where notifications can be published.
+func (s *LoadBalancedWebService) Publish() []Topic {
+	if s.LoadBalancedWebServiceConfig.Publish == nil {
+		return nil
+	}
+	return s.LoadBalancedWebServiceConfig.Publish.Topics
+}
+
 // BuildRequired returns if the service requires building from the local Dockerfile.
 func (s *LoadBalancedWebService) BuildRequired() (bool, error) {
 	return requiresBuild(s.ImageConfig.Image)
 }
 
-// TaskPlatform returns the os/arch for the service.
-func (t *TaskConfig) TaskPlatform() (*string, error) {
-	if err := exec.ValidatePlatform(t.Platform); err != nil {
-		return nil, fmt.Errorf("validate platform: %w", err)
-	}
-	return t.Platform, nil
-}
-
 // BuildArgs returns a docker.BuildArguments object given a ws root directory.
 func (s *LoadBalancedWebService) BuildArgs(wsRoot string) *DockerBuildArgs {
 	return s.ImageConfig.BuildConfig(wsRoot)
@@ -167,19 +157,53 @@ func (s LoadBalancedWebService) ApplyEnv(envName string) (WorkloadManifest, erro
 		return &s, nil
 	}
 
-	envCount := overrideConfig.TaskConfig.Count
-	if !envCount.IsEmpty() {
-		s.TaskConfig.Count = envCount
+	for _, t := range defaultTransformers {
+		// Apply overrides to the original service s.
+		err := mergo.Merge(&s, LoadBalancedWebService{
+			LoadBalancedWebServiceConfig: *overrideConfig,
+		}, mergo.WithOverride, mergo.WithTransformers(t))
+
+		if err != nil {
+			return nil, err
+		}
 	}
 
-	// Apply overrides to the original service s.
-	err := mergo.Merge(&s, LoadBalancedWebService{
-		LoadBalancedWebServiceConfig: *overrideConfig,
-	}, mergo.WithOverride, mergo.WithOverwriteWithEmptyValue, mergo.WithTransformers(workloadTransformer{}))
-
-	if err != nil {
-		return nil, err
-	}
 	s.Environments = nil
 	return &s, nil
 }
+
+// RoutingRule holds the path to route requests to the service.
+type RoutingRule struct {
+	Path                *string                 `yaml:"path"`
+	HealthCheck         HealthCheckArgsOrString `yaml:"healthcheck"`
+	Stickiness          *bool                   `yaml:"stickiness"`
+	Alias               *Alias                  `yaml:"alias"`
+	DeregistrationDelay *time.Duration          `yaml:"deregistration_delay"`
+	// TargetContainer is the container load balancer routes traffic to.
+	TargetContainer          *string   `yaml:"target_container"`
+	TargetContainerCamelCase *string   `yaml:"targetContainer"`    // "targetContainerCamelCase" for backwards compatibility
+	AllowedSourceIps         *[]string `yaml:"allowed_source_ips"` // TODO: the type needs to be updated after we upgrade mergo
+}
+
+// Alias is a custom type which supports unmarshaling "http.alias" yaml which
+// can either be of type string or type slice of string.
+type Alias stringSliceOrString
+
+// UnmarshalYAML overrides the default YAML unmarshaling logic for the Alias
+// struct, allowing it to perform more complex unmarshaling behavior.
+// This method implements the yaml.Unmarshaler (v2) interface.
+func (e *Alias) UnmarshalYAML(unmarshal func(interface{}) error) error {
+	if err := unmarshalYAMLToStringSliceOrString((*stringSliceOrString)(e), unmarshal); err != nil {
+		return errUnmarshalEntryPoint
+	}
+	return nil
+}
+
+// ToStringSlice converts an Alias to a slice of string using shell-style rules.
+func (e *Alias) ToStringSlice() ([]string, error) {
+	out, err := toStringSlice((*stringSliceOrString)(e))
+	if err != nil {
+		return nil, err
+	}
+	return out, nil
+}
