@@ -4,23 +4,17 @@
 package manifest
 
 import (
-	"errors"
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/imdario/mergo"
-	"gopkg.in/yaml.v3"
 )
 
 const (
 	workerSvcManifestPath = "workloads/services/worker/manifest.yml"
 )
 
-var (
-	errUnmarshalFIFO = errors.New("cannot unmarshal field `fifo` under `subscribe`")
-)
-
 // WorkerService holds the configuration to create a worker service.
 type WorkerService struct {
 	Workload            `yaml:",inline"`
@@ -33,26 +27,20 @@ type WorkerService struct {
 
 // WorkerServiceConfig holds the configuration that can be overridden per environments.
 type WorkerServiceConfig struct {
-	ImageConfig   ImageWithHealthcheck `yaml:"image,flow"`
-	ImageOverride `yaml:",inline"`
-	TaskConfig    `yaml:",inline"`
-	*Logging      `yaml:"logging,flow"`
-	Sidecars      map[string]*SidecarConfig `yaml:"sidecars"`
-	Subscribe     *SubscribeConfig          `yaml:"subscribe"`
-	Network       *NetworkConfig            `yaml:"network"`
-}
-
-// WorkerServiceProps represents the configuration needed to create a worker service.
-type WorkerServiceProps struct {
-	WorkloadProps
-	HealthCheck *ContainerHealthCheck // Optional healthcheck configuration.
-	Topics      *[]TopicSubscription  // Optional topics for subscriptions
+	ImageConfig      ImageWithHealthcheck `yaml:"image,flow"`
+	ImageOverride    `yaml:",inline"`
+	TaskConfig       `yaml:",inline"`
+	*Logging         `yaml:"logging,flow"`
+	Sidecars         map[string]*SidecarConfig `yaml:"sidecars"`
+	Subscribe        *SubscribeConfig          `yaml:"subscribe"`
+	Network          *NetworkConfig            `yaml:"network"`
+	TaskDefOverrides []OverrideRule            `yaml:"taskdef_overrides"`
 }
 
 // SubscribeConfig represents the configurable options for setting up subscriptions.
 type SubscribeConfig struct {
-	Topics *[]TopicSubscription `yaml:"topics"`
-	Queue  *SQSQueue            `yaml:"queue"`
+	Topics []TopicSubscription `yaml:"topics"`
+	Queue  *SQSQueue           `yaml:"queue"`
 }
 
 // TopicSubscription represents the configurable options for setting up a SNS Topic Subscription.
@@ -68,7 +56,6 @@ type SQSQueue struct {
 	Delay      *time.Duration   `yaml:"delay"`
 	Timeout    *time.Duration   `yaml:"timeout"`
 	DeadLetter *DeadLetterQueue `yaml:"dead_letter"`
-	FIFO       *FIFOOrBool      `yaml:"fifo"`
 }
 
 // DeadLetterQueue represents the configurable options for setting up a Dead-Letter Queue.
@@ -76,43 +63,11 @@ type DeadLetterQueue struct {
 	Tries *uint16 `yaml:"tries"`
 }
 
-// FIFOOrBool contains custom unmarshaling logic for the `fifo` field in the manifest.
-type FIFOOrBool struct {
-	FIFO    FIFOQueue
-	Enabled *bool
-}
-
-// FIFOQueue represents the configurable options for setting up a FIFO queue.
-type FIFOQueue struct {
-	HighThroughput *bool `yaml:"high_throughput"`
-}
-
-// IsEmpty returns empty if the struct has all zero members.
-func (q *FIFOQueue) IsEmpty() bool {
-	return q.HighThroughput == nil
-}
-
-// UnmarshalYAML implements the yaml(v2) interface. It allows FIFOQueue to be specified as a
-// string or a struct alternately.
-func (q *FIFOOrBool) UnmarshalYAML(unmarshal func(interface{}) error) error {
-	if err := unmarshal(&q.FIFO); err != nil {
-		switch err.(type) {
-		case *yaml.TypeError:
-			break
-		default:
-			return err
-		}
-	}
-
-	if !q.FIFO.IsEmpty() {
-		q.Enabled = nil
-		return nil
-	}
-
-	if err := unmarshal(&q.Enabled); err != nil {
-		return errUnmarshalFIFO
-	}
-	return nil
+// WorkerServiceProps represents the configuration needed to create a worker service.
+type WorkerServiceProps struct {
+	WorkloadProps
+	HealthCheck *ContainerHealthCheck // Optional healthcheck configuration.
+	Topics      []TopicSubscription   // Optional topics for subscriptions
 }
 
 // NewWorkerService applies the props to a default Worker service configuration with
@@ -129,6 +84,64 @@ func NewWorkerService(props WorkerServiceProps) *WorkerService {
 	return svc
 }
 
+// MarshalBinary serializes the manifest object into a binary YAML document.
+// Implements the encoding.BinaryMarshaler interface.
+func (s *WorkerService) MarshalBinary() ([]byte, error) {
+	content, err := s.parser.Parse(workerSvcManifestPath, *s, template.WithFuncs(map[string]interface{}{
+		"fmtSlice":   template.FmtSliceFunc,
+		"quoteSlice": template.QuoteSliceFunc,
+	}))
+	if err != nil {
+		return nil, err
+	}
+	return content.Bytes(), nil
+}
+
+// BuildRequired returns if the service requires building from the local Dockerfile.
+func (s *WorkerService) BuildRequired() (bool, error) {
+	return requiresBuild(s.ImageConfig.Image)
+}
+
+// BuildArgs returns a docker.BuildArguments object for the service given a workspace root directory
+func (s *WorkerService) BuildArgs(wsRoot string) *DockerBuildArgs {
+	return s.ImageConfig.BuildConfig(wsRoot)
+}
+
+// Subscriptions returns a list of TopicSubscriotion objects which represent the SNS topics the service
+// receives messages from.
+func (s *WorkerService) Subscriptions() []TopicSubscription {
+	if s.Subscribe != nil {
+		return s.Subscribe.Topics
+	}
+	return nil
+}
+
+// ApplyEnv returns the service manifest with environment overrides.
+// If the environment passed in does not have any overrides then it returns itself.
+func (s WorkerService) ApplyEnv(envName string) (WorkloadManifest, error) {
+	overrideConfig, ok := s.Environments[envName]
+	if !ok {
+		return &s, nil
+	}
+
+	if overrideConfig == nil {
+		return &s, nil
+	}
+
+	// Apply overrides to the original service s.
+	for _, t := range defaultTransformers {
+		err := mergo.Merge(&s, WorkerService{
+			WorkerServiceConfig: *overrideConfig,
+		}, mergo.WithOverride, mergo.WithTransformers(t))
+
+		if err != nil {
+			return nil, err
+		}
+	}
+	s.Environments = nil
+	return &s, nil
+}
+
 // newDefaultWorkerService returns a Worker service with minimal task sizes and a single replica.
 func newDefaultWorkerService() *WorkerService {
 	return &WorkerService{
@@ -156,55 +169,3 @@ func newDefaultWorkerService() *WorkerService {
 		},
 	}
 }
-
-// MarshalBinary serializes the manifest object into a binary YAML document.
-// Implements the encoding.BinaryMarshaler interface.
-func (s *WorkerService) MarshalBinary() ([]byte, error) {
-	content, err := s.parser.Parse(workerSvcManifestPath, *s, template.WithFuncs(map[string]interface{}{
-		"fmtSlice":   template.FmtSliceFunc,
-		"quoteSlice": template.QuoteSliceFunc,
-	}))
-	if err != nil {
-		return nil, err
-	}
-	return content.Bytes(), nil
-}
-
-// BuildRequired returns if the service requires building from the local Dockerfile.
-func (s *WorkerService) BuildRequired() (bool, error) {
-	return requiresBuild(s.ImageConfig.Image)
-}
-
-// BuildArgs returns a docker.BuildArguments object for the service given a workspace root directory
-func (s *WorkerService) BuildArgs(wsRoot string) *DockerBuildArgs {
-	return s.ImageConfig.BuildConfig(wsRoot)
-}
-
-// ApplyEnv returns the service manifest with environment overrides.
-// If the environment passed in does not have any overrides then it returns itself.
-func (s WorkerService) ApplyEnv(envName string) (WorkloadManifest, error) {
-	overrideConfig, ok := s.Environments[envName]
-	if !ok {
-		return &s, nil
-	}
-
-	if overrideConfig == nil {
-		return &s, nil
-	}
-
-	envCount := overrideConfig.TaskConfig.Count
-	if !envCount.IsEmpty() {
-		s.TaskConfig.Count = envCount
-	}
-
-	// Apply overrides to the original service s.
-	err := mergo.Merge(&s, WorkerService{
-		WorkerServiceConfig: *overrideConfig,
-	}, mergo.WithOverride, mergo.WithOverwriteWithEmptyValue, mergo.WithTransformers(workloadTransformer{}))
-
-	if err != nil {
-		return nil, err
-	}
-	s.Environments = nil
-	return &s, nil
-}
