@@ -8,6 +8,8 @@ import (
 	"fmt"
 	"text/template"
 
+	"github.com/dustin/go-humanize/english"
+
 	"github.com/google/uuid"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -220,7 +222,7 @@ type PublishOpts struct {
 	Topics []*Topic
 }
 
-// Topics holds information needed to render a SNSTopic in a container definition.
+// Topic holds information needed to render a SNSTopic in a container definition.
 type Topic struct {
 	Name           *string
 	AllowedWorkers []string
@@ -239,6 +241,16 @@ type SubscribeOpts struct {
 	Queue  *SQSQueue
 }
 
+// HasTopicQueues returns true if any individual subscription has a dedicated queue.
+func (s *SubscribeOpts) HasTopicQueues() bool {
+	for _, t := range s.Topics {
+		if t.Queue != nil {
+			return true
+		}
+	}
+	return false
+}
+
 // TopicSubscription holds information needed to render a SNS Topic Subscription in a container definition.
 type TopicSubscription struct {
 	Name    *string
@@ -252,7 +264,6 @@ type SQSQueue struct {
 	Delay      *int64
 	Timeout    *int64
 	DeadLetter *DeadLetterQueue
-	FIFO       *FIFOQueue
 }
 
 // DeadLetterQueue holds information needed to render a dead-letter SQS Queue in a container definition.
@@ -260,11 +271,6 @@ type DeadLetterQueue struct {
 	Tries *uint16
 }
 
-// FIFOQueue holds information needed to specify a SQS Queue as FIFO in a container definition.
-type FIFOQueue struct {
-	HighThroughput bool
-}
-
 // NetworkOpts holds AWS networking configuration for the workloads.
 type NetworkOpts struct {
 	AssignPublicIP string
@@ -319,7 +325,7 @@ type WorkloadOpts struct {
 	StateMachine       *StateMachineOpts
 
 	// Additional options for worker service templates.
-	Subscribe SubscribeOpts
+	Subscribe *SubscribeOpts
 }
 
 // ParseRequestDrivenWebServiceInput holds data that can be provided to enable features for a request-driven web service stack.
@@ -424,6 +430,8 @@ func withSvcParsingFuncs() ParseOption {
 			"jsonQueueURIs":       generateQueueURIJSON,
 			"envControllerParams": envControllerParameters,
 			"logicalIDSafe":       StripNonAlphaNumFunc,
+			"wordSeries":          english.WordSeries,
+			"pluralWord":          english.PluralWord,
 		})
 	}
 }
