@@ -29,6 +29,173 @@ type deploySelectMocks struct {
 	prompt    *mocks.MockPrompter
 }
 
+func TestDeploySelect_Topics(t *testing.T) {
+	const (
+		testApp = "mockApp"
+		testEnv = "mockEnv"
+		prodEnv = "mockProdEnv"
+	)
+	mockTopic, _ := deploy.NewTopic("arn:aws:sns:us-west-2:123456789012:mockApp-mockEnv-mockWkld-orders", testApp, testEnv, "mockWkld")
+	mockTopic2, _ := deploy.NewTopic("arn:aws:sns:us-west-2:123456789012:mockApp-mockEnv-mockWkld-events", testApp, testEnv, "mockWkld")
+	testCases := map[string]struct {
+		setupMocks func(mocks deploySelectMocks)
+
+		wantErr    error
+		wantTopics []deploy.Topic
+	}{
+		"return error if fail to retrieve topics from deploy": {
+			setupMocks: func(m deploySelectMocks) {
+				m.configSvc.EXPECT().ListEnvironments(testApp).Return(
+					[]*config.Environment{{Name: testEnv}}, nil,
+				)
+				m.deploySvc.
+					EXPECT().
+					ListSNSTopics(testApp, testEnv).
+					Return(nil, errors.New("some error"))
+			},
+			wantErr: fmt.Errorf("list SNS topics: some error"),
+		},
+		"return error if fail to select topics": {
+			setupMocks: func(m deploySelectMocks) {
+				m.configSvc.EXPECT().ListEnvironments(testApp).Return(
+					[]*config.Environment{{Name: testEnv}}, nil,
+				)
+				m.deploySvc.
+					EXPECT().
+					ListSNSTopics(testApp, testEnv).
+					Return([]deploy.Topic{*mockTopic}, nil)
+				m.prompt.
+					EXPECT().
+					MultiSelect("Select a deployed topic", "Help text", []string{"orders (mockWkld)"}, gomock.Any()).
+					Return(nil, errors.New("some error"))
+			},
+			wantErr: fmt.Errorf("select SNS topics: some error"),
+		},
+		"success": {
+			setupMocks: func(m deploySelectMocks) {
+				m.configSvc.EXPECT().ListEnvironments(testApp).Return(
+					[]*config.Environment{{Name: testEnv}, {Name: prodEnv}}, nil,
+				)
+				m.deploySvc.
+					EXPECT().
+					ListSNSTopics(testApp, testEnv).
+					Return([]deploy.Topic{*mockTopic, *mockTopic2}, nil)
+				m.deploySvc.
+					EXPECT().
+					ListSNSTopics(testApp, prodEnv).
+					Return([]deploy.Topic{*mockTopic}, nil)
+				m.prompt.
+					EXPECT().
+					MultiSelect("Select a deployed topic", "Help text", []string{"orders (mockWkld)"}, gomock.Any()).
+					Return([]string{"orders (mockWkld)"}, nil)
+			},
+			wantTopics: []deploy.Topic{*mockTopic},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			ctrl := gomock.NewController(t)
+			defer ctrl.Finish()
+
+			mockdeploySvc := mocks.NewMockDeployStoreClient(ctrl)
+			mockconfigSvc := mocks.NewMockConfigLister(ctrl)
+			mockprompt := mocks.NewMockPrompter(ctrl)
+			mocks := deploySelectMocks{
+				deploySvc: mockdeploySvc,
+				configSvc: mockconfigSvc,
+				prompt:    mockprompt,
+			}
+
+			tc.setupMocks(mocks)
+
+			sel := DeploySelect{
+				Select: &Select{
+					config: mockconfigSvc,
+					prompt: mockprompt,
+				},
+				deployStoreSvc: mockdeploySvc,
+			}
+			topics, err := sel.Topics("Select a deployed topic", "Help text", testApp)
+			if tc.wantErr != nil {
+				require.EqualError(t, tc.wantErr, err.Error())
+			} else {
+				require.Equal(t, tc.wantTopics, topics)
+			}
+		})
+	}
+}
+
+func TestIntersect(t *testing.T) {
+	mockTopic1Env1, _ := deploy.NewTopic("arn:aws:sns:us-west-2:123456789012:mockApp-mockEnv1-mockWkld-orders", "mockApp", "mockEnv1", "mockWkld")
+	mockTopic1Env2, _ := deploy.NewTopic("arn:aws:sns:us-west-2:123456789012:mockApp-mockEnv2-mockWkld-orders", "mockApp", "mockEnv2", "mockWkld")
+	mockTopic2Env1, _ := deploy.NewTopic("arn:aws:sns:us-west-2:123456789012:mockApp-mockEnv1-mockWkld2-events", "mockApp", "mockEnv1", "mockWkld2")
+	mockTopic2Env2, _ := deploy.NewTopic("arn:aws:sns:us-west-2:123456789012:mockApp-mockEnv2-mockWkld2-events", "mockApp", "mockEnv2", "mockWkld2")
+	testCases := map[string]struct {
+		inArray []deploy.Topic
+		inMap   map[string]deploy.Topic
+
+		wantedMap map[string]deploy.Topic
+	}{
+		"with no common entries": {
+			inArray: []deploy.Topic{
+				*mockTopic1Env1,
+			},
+			inMap: map[string]deploy.Topic{
+				mockTopic2Env2.String(): *mockTopic2Env2,
+			},
+			wantedMap: map[string]deploy.Topic{},
+		},
+		"with common entries": {
+			inArray: []deploy.Topic{
+				*mockTopic1Env1,
+				*mockTopic2Env1,
+			},
+			inMap: map[string]deploy.Topic{
+				mockTopic2Env2.String(): *mockTopic2Env2,
+				mockTopic1Env2.String(): *mockTopic1Env2,
+			},
+			wantedMap: map[string]deploy.Topic{
+				mockTopic2Env1.String(): *mockTopic2Env1,
+				mockTopic1Env1.String(): *mockTopic1Env1,
+			},
+		},
+		"with one common entry, extra entry in array": {
+			inArray: []deploy.Topic{
+				*mockTopic1Env1,
+				*mockTopic2Env1,
+			},
+			inMap: map[string]deploy.Topic{
+				mockTopic2Env2.String(): *mockTopic2Env2,
+			},
+			wantedMap: map[string]deploy.Topic{
+				mockTopic2Env1.String(): *mockTopic2Env1,
+			},
+		},
+		"with one common entry, extra entry in map": {
+			inArray: []deploy.Topic{
+				*mockTopic1Env1,
+			},
+			inMap: map[string]deploy.Topic{
+				mockTopic2Env2.String(): *mockTopic2Env2,
+				mockTopic1Env2.String(): *mockTopic1Env2,
+			},
+			wantedMap: map[string]deploy.Topic{
+				mockTopic1Env1.String(): *mockTopic1Env1,
+			},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// GIVEN
+
+			// WHEN
+			out := intersect(tc.inMap, tc.inArray)
+
+			// THEN
+			require.Equal(t, out, tc.wantedMap)
+		})
+	}
+}
 func TestDeploySelect_Service(t *testing.T) {
 	const testApp = "mockApp"
 	testCases := map[string]struct {
@@ -105,7 +272,7 @@ func TestDeploySelect_Service(t *testing.T) {
 
 				m.prompt.
 					EXPECT().
-					SelectOne("Select a deployed service", "Help text", []string{"mockSvc1 (test)", "mockSvc2 (test)"}).
+					SelectOne("Select a deployed service", "Help text", []string{"mockSvc1 (test)", "mockSvc2 (test)"}, gomock.Any()).
 					Return("", errors.New("some error"))
 			},
 			wantErr: fmt.Errorf("select deployed services for application %s: some error", testApp),
@@ -128,7 +295,7 @@ func TestDeploySelect_Service(t *testing.T) {
 
 				m.prompt.
 					EXPECT().
-					SelectOne("Select a deployed service", "Help text", []string{"mockSvc1 (test)", "mockSvc2 (test)"}).
+					SelectOne("Select a deployed service", "Help text", []string{"mockSvc1 (test)", "mockSvc2 (test)"}, gomock.Any()).
 					Return("mockSvc1 (test)", nil)
 			},
 			wantEnv: "test",
@@ -225,7 +392,7 @@ func TestDeploySelect_Service(t *testing.T) {
 
 				m.prompt.
 					EXPECT().
-					SelectOne("Select a deployed service", "Help text", []string{"mockSvc1 (test1)", "mockSvc2 (test1)"}).
+					SelectOne("Select a deployed service", "Help text", []string{"mockSvc1 (test1)", "mockSvc2 (test1)"}, gomock.Any()).
 					Return("mockSvc1 (test1)", nil)
 			},
 			wantEnv: "test1",
@@ -918,7 +1085,7 @@ func TestConfigSelect_Service(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -939,7 +1106,7 @@ func TestConfigSelect_Service(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -968,7 +1135,8 @@ func TestConfigSelect_Service(t *testing.T) {
 					SelectOne(
 						gomock.Eq("Select a service"),
 						gomock.Eq("Help text"),
-						gomock.Eq([]string{"service1", "service2"})).
+						gomock.Eq([]string{"service1", "service2"}),
+						gomock.Any()).
 					Return("service2", nil).
 					Times(1)
 			},
@@ -994,7 +1162,7 @@ func TestConfigSelect_Service(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"service1", "service2"})).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"service1", "service2"}), gomock.Any()).
 					Return("", fmt.Errorf("error selecting")).
 					Times(1)
 			},
@@ -1048,7 +1216,7 @@ func TestConfigSelect_Job(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -1069,7 +1237,7 @@ func TestConfigSelect_Job(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -1098,7 +1266,8 @@ func TestConfigSelect_Job(t *testing.T) {
 					SelectOne(
 						gomock.Eq("Select a job"),
 						gomock.Eq("Help text"),
-						gomock.Eq([]string{"job1", "job2"})).
+						gomock.Eq([]string{"job1", "job2"}),
+						gomock.Any()).
 					Return("job2", nil).
 					Times(1)
 			},
@@ -1124,7 +1293,7 @@ func TestConfigSelect_Job(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"job1", "job2"})).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"job1", "job2"}), gomock.Any()).
 					Return("", fmt.Errorf("error selecting")).
 					Times(1)
 			},
@@ -1187,7 +1356,7 @@ func TestSelect_Environment(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -1207,7 +1376,7 @@ func TestSelect_Environment(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -1234,7 +1403,8 @@ func TestSelect_Environment(t *testing.T) {
 					SelectOne(
 						gomock.Eq("Select an environment"),
 						gomock.Eq("Help text"),
-						gomock.Eq([]string{"env1", "env2"})).
+						gomock.Eq([]string{"env1", "env2"}),
+						gomock.Any()).
 					Return("env2", nil).
 					Times(1)
 			},
@@ -1258,7 +1428,7 @@ func TestSelect_Environment(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"env1", "env2"})).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"env1", "env2"}), gomock.Any()).
 					Return("", fmt.Errorf("error selecting")).
 					Times(1)
 			},
@@ -1274,7 +1444,7 @@ func TestSelect_Environment(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 			},
 
@@ -1290,7 +1460,7 @@ func TestSelect_Environment(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), []string{additionalOpt1, additionalOpt2}).
+					SelectOne(gomock.Any(), gomock.Any(), []string{additionalOpt1, additionalOpt2}, gomock.Any()).
 					Times(1).
 					Return(additionalOpt2, nil)
 			},
@@ -1556,7 +1726,7 @@ func TestSelect_Application(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -1575,7 +1745,7 @@ func TestSelect_Application(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Any()).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Any(), gomock.Any()).
 					Times(0)
 
 			},
@@ -1600,7 +1770,8 @@ func TestSelect_Application(t *testing.T) {
 					SelectOne(
 						gomock.Eq("Select an app"),
 						gomock.Eq("Help text"),
-						gomock.Eq([]string{"app1", "app2"})).
+						gomock.Eq([]string{"app1", "app2"}),
+						gomock.Any()).
 					Return("app2", nil).
 					Times(1)
 			},
@@ -1622,7 +1793,7 @@ func TestSelect_Application(t *testing.T) {
 					Times(1)
 				m.prompt.
 					EXPECT().
-					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"app1", "app2"})).
+					SelectOne(gomock.Any(), gomock.Any(), gomock.Eq([]string{"app1", "app2"}), gomock.Any()).
 					Return("", fmt.Errorf("error selecting")).
 					Times(1)
 			},
@@ -1970,6 +2141,7 @@ func TestSelect_CFTask(t *testing.T) {
 						"abc",
 						"db-migrate",
 					},
+					gomock.Any(),
 				).Return("abc", nil)
 			},
 			wantedErr:  nil,
@@ -2008,6 +2180,7 @@ func TestSelect_CFTask(t *testing.T) {
 						"oneoff",
 						"db-migrate",
 					},
+					gomock.Any(),
 				).Return("db-migrate", nil)
 			},
 			wantedErr:  nil,
@@ -2137,7 +2310,7 @@ func TestTaskSelect_Task(t *testing.T) {
 				m.prompt.EXPECT().SelectOne(mockPromptText, mockHelpText, []string{
 					"4082490e (sample-fargate:2)",
 					"0aa1ba8d (sample-fargate:3)",
-				}).Return("", mockErr)
+				}, gomock.Any()).Return("", mockErr)
 			},
 			wantErr: fmt.Errorf("select running task: some error"),
 		},
@@ -2169,7 +2342,7 @@ func TestTaskSelect_Task(t *testing.T) {
 				m.prompt.EXPECT().SelectOne(mockPromptText, mockHelpText, []string{
 					"4082490e (sample-fargate:2)",
 					"0aa1ba8d (sample-fargate:3)",
-				}).Return("0aa1ba8d (sample-fargate:3)", nil)
+				}, gomock.Any()).Return("0aa1ba8d (sample-fargate:3)", nil)
 			},
 			wantTask: mockTask2,
 		},
